@@ -11,8 +11,9 @@
 #' ds <- tbl_df(mtcars)
 #' ds
 #' as.data.frame(ds)
-#' 
-#' library(Lahman)
+#'
+#' if (require("Lahman")) {
+#' data("Batting", package = "Lahman")
 #' batting <- tbl_df(Batting)
 #' dim(batting)
 #' colnames(batting)
@@ -24,7 +25,7 @@
 #' arrange(batting, playerID, desc(yearID))
 #' summarise(batting, G = mean(G), n = n())
 #' mutate(batting, rbi2 = if(is.null(AB)) 1.0 * R / AB else 0)
-#' 
+#'
 #' # Group by operations -------------------------------------------------------
 #' # To perform operations by group, create a grouped object with group_by
 #' players <- group_by(batting, playerID)
@@ -32,9 +33,9 @@
 #'
 #' summarise(players, mean_g = mean(G), best_ab = max(AB))
 #' best_year <- filter(players, AB == max(AB) | G == max(G))
-#' progress <- mutate(players, cyear = yearID - min(yearID) + 1, 
+#' progress <- mutate(players, cyear = yearID - min(yearID) + 1,
 #'  rank(desc(AB)), cumsum(AB))
-#'  
+#'
 #' # When you group by multiple level, each summarise peels off one level
 #' per_year <- group_by(batting, playerID, yearID)
 #' stints <- summarise(per_year, stints = max(stint))
@@ -46,7 +47,7 @@
 #' player_info <- select(tbl_df(Master), playerID, hofID, birthYear)
 #' hof <- select(filter(tbl_df(HallOfFame), inducted == "Y"),
 #'  hofID, votedBy, category)
-#' 
+#'
 #' # Match players and their hall of fame data
 #' inner_join(player_info, hof)
 #' # Keep all players, match hof data where available
@@ -55,12 +56,10 @@
 #' semi_join(player_info, hof)
 #' # Find players not in hof
 #' anti_join(player_info, hof)
+#' }
 tbl_df <- function(data) {
   assert_that(is.data.frame(data))
-  if (is.grouped_df(data)) return(ungroup(data))
-  
-  class(data) <- c("tbl_df", "tbl", "data.frame")
-  data
+  tbl_df_impl(data)
 }
 
 #' @export
@@ -84,8 +83,7 @@ same_src.data.frame <- function(x, y) {
 
 #' @export
 as.data.frame.tbl_df <- function(x, row.names = NULL, optional = FALSE, ...) {
-  class(x) <- "data.frame"
-  x
+  as_regular_df(x)
 }
 
 #' @export
