@@ -8,7 +8,11 @@ namespace Rcpp {
     public:
         typedef typename traits::storage_type<RTYPE>::type STORAGE ;
         
-        ShrinkableVector( int n ) : data( no_init(n) ), max_size(n), start( internal::r_vector_start<RTYPE>(data) ) {}
+        ShrinkableVector( int n, SEXP origin ) : 
+          data( no_init(n) ), max_size(n), start( internal::r_vector_start<RTYPE>(data) ) 
+        {
+            copy_attributes(data, origin) ;
+        }
         
         inline void resize( int n){
             SETLENGTH( data, n ) ;    
